Dataclasses
===========
Example factories for models based on
`dataclasses <https://docs.python.org/3/library/dataclasses.html>`_.

Testing
-------
.. code-block:: sh

    pytest

or

.. code-block:: sh

    python manage.py test
